DebugQuery

Trait DebugQuery 

pub trait DebugQuery: Debug + Display { }
A helper trait for opaque query representations which allows to get a Display and Debug representation of the underlying type without exposing type specific details

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl DebugQuery for StrQueryHelper<'_>

Source

impl<T, DB> DebugQuery for DebugQuery<'_, T, DB>
where Self: Debug + Display,